#!/usr/bin/python

#
# Copyright 2012 Canonical Ltd.
#
# Authors:
#  Andres Rodriguez <andres.rodriguez@canonical.com>
#

import glob
import os
import subprocess
import shutil
import sys

import utils


def install():
    utils.juju_log('INFO', 'Begin install hook.')
    utils.configure_source()
    utils.install('corosync', 'pacemaker')
    utils.juju_log('INFO', 'End install hook.')


def emit_corosync_conf():
    # read config variables
    corosync_conf_context = {
        'corosync_bindnetaddr': utils.config_get('corosync_bindnetaddr'),
        'corosync_mcastaddr': utils.config_get('corosync_mcastaddr'),
        'corosync_mcastport': utils.config_get('corosync_mcastport'),
        'corosync_pcmk_ver': utils.config_get('corosync_pcmk_ver'),
        }

    # write /etc/default/corosync file
    with open('/etc/default/corosync', 'w') as corosync_default:
        corosync_default.write(utils.render_template('corosync', corosync_conf_context))

    # write config file (/etc/corosync/corosync.conf
    with open('/etc/corosync/corosync.conf', 'w') as corosync_conf:
        corosync_conf.write(utils.render_template('corosync.conf', corosync_conf_context))

    # write the authkey
    corosync_key=utils.config_get('corosync_key')
    with open(corosync_key, 'w') as corosync_key_file:
        corosync_key_file.write(corosync_key)


def config_changed():
    utils.juju_log('INFO', 'Begin config-changed hook.')

    # validate configuration options
    corosync_bindnetaddr = utils.config_get('corosync_bindnetaddr')
    if corosync_bindnetaddr == '':
        utils.juju_log('CRITICAL', 'No bindnetaddr supplied, cannot proceed.')
        sys.exit(1)

    corosync_key = utils.config_get('corosync_key')
    if corosync_key == '':
        utils.juju_log('CRITICAL',
                       'No Corosync key supplied, cannot proceed')
        sys.exit(1)

    # Create a new config file
    emit_corosync_conf()

    utils.juju_log('INFO', 'End config-changed hook.')


def upgrade_charm():
    utils.juju_log('INFO', 'Begin upgrade-charm hook.')
    emit_corosync_conf()
    utils.juju_log('INFO', 'End upgrade-charm hook.')


def service(service=None, action=None):
    if action is None or service is None:
        return(None)
    else:
        retVal = subprocess.call(['service', service, action])
        if retVal == 0:
            return(True)
        else:
            return(False)


def start():
    if service("corosync", "status"):
        service("corosync", "restart")
    else:
        service("corosync", "start")

    if service("pacemaker", "status"):
        service("pacemaker", "restart")
    else:
        service("pacemaker", "start")

utils.do_hooks({
        'config-changed': config_changed,
        'install': install,
        'start': start,
        'upgrade-charm': upgrade_charm,
        })

sys.exit(0)
